@@ -18,7 +18,7 @@ fieldhash my %graph   => 'graph';
 fieldhash my %logger  => 'logger';
 fieldhash my %tree    => 'tree';
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 # -----------------------------------------------
 # This is a function.
@@ -377,7 +377,7 @@ L<GraphViz2::Data::Grapher> - Visualize a data structure as a graph
 		(
 		 edge   => {color => 'grey'},
 		 global => {directed => 1},
-		 graph  => {rankdir => 'TB', label => "Graph produced by GraphViz2::Data::Grapher's $0"},
+		 graph  => {rankdir => 'TB'},
 		 logger => $logger,
 		 node   => {color => 'darkblue', shape => 'oval'},
 		);
@@ -387,19 +387,19 @@ L<GraphViz2::Data::Grapher> - Visualize a data structure as a graph
 	my($output_file) = shift || File::Spec -> catfile('html', "parse.data.$format");
 	
 	$g -> create(name => 's', thing => $s);
-	$graph -> run(format => $format, output_file => $output_file, timeout => 11);
+	$graph -> run(format => $format, output_file => $output_file);
 	
 	# If you did not provide a GraphViz2 object, do this
 	# to get access to the auto-created GraphViz2 object.
 	
 	#$g -> create(name => 's', thing => $s);
-	#$g -> graph -> run(format => $format, output_file => $output_file, timeout => 11);
+	#$g -> graph -> run(format => $format, output_file => $output_file);
 	
 	# Or even
 	
 	#$g -> create(name => 's', thing => $s)
 	#-> graph
-	#-> run(format => $format, output_file => $output_file, timeout => 11);
+	#-> run(format => $format, output_file => $output_file);
 
 See scripts/parse.data.pl (L<GraphViz2/Scripts Shipped with this Module>).
 
