@@ -9,7 +9,7 @@ use Hash::FieldHash ':all';
 
 fieldhash my %graph => 'graph';
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 # -----------------------------------------------
 
@@ -220,7 +220,7 @@ L<GraphViz2::Parse::Marpa> - Visualize a Marpa grammar as a graph
 		(
 		 edge   => {color => 'grey'},
 		 global => {directed => 1, record_orientation => 'horizontal'},
-		 graph  => {rankdir => 'TB', label => "Graph produced by GraphViz2::Data::Grapher's $0"},
+		 graph  => {rankdir => 'TB'},
 		 logger => $logger,
 		 node   => {color => 'blue', shape => 'oval'},
 		);
@@ -232,7 +232,7 @@ L<GraphViz2::Parse::Marpa> - Visualize a Marpa grammar as a graph
 	my($format)      = shift || 'svg';
 	my($output_file) = shift || File::Spec -> catfile('html', "parse.marpa.$format");
 	
-	$graph -> run(format => $format, output_file => $output_file, timeout => 11);
+	$graph -> run(format => $format, output_file => $output_file);
 
 See scripts/parse.marpa.pl (L<GraphViz2/Scripts Shipped with this Module>).
 
