@@ -11,7 +11,7 @@ use Perl6::Slurp;
 
 fieldhash my %graph => 'graph';
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 # -----------------------------------------------
 
@@ -148,7 +148,7 @@ L<GraphViz2::Parse::Yapp> - Visualize a yapp grammar as a graph
 		(
 		 edge   => {color => 'grey'},
 		 global => {directed => 1},
-		 graph  => {concentrate => 1, rankdir => 'TB', label => "Graph produced by GraphViz2::Data::Grapher's $0"},
+		 graph  => {concentrate => 1, rankdir => 'TB'},
 		 logger => $logger,
 		 node   => {color => 'darkblue', shape => 'oval'},
 		);
@@ -159,7 +159,7 @@ L<GraphViz2::Parse::Yapp> - Visualize a yapp grammar as a graph
 	my($format)      = shift || 'svg';
 	my($output_file) = shift || File::Spec -> catfile('html', "parse.yapp.$format");
 	
-	$graph -> run(format => $format, output_file => $output_file, timeout => 11);
+	$graph -> run(format => $format, output_file => $output_file);
 
 See scripts/parse.yapp.pl (L<GraphViz2/Scripts Shipped with this Module>).
 
